<?php if(! defined('WPS_PLUGIN_PREFIX')) return;
/**
 * Class WsdCheck
 * Static class. Provides security checks for Wordpress
 */
class WsdCheck extends WsdPlugin
{
    // type: stack - cron
    public static function adminUsername()
    {
        global $wpdb, $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['check_username_admin']['name'];
        $alertType = $wpsPluginAlertsArray['check_username_admin']['type'];

        $u = $wpdb->get_var("SELECT `ID` FROM $wpdb->users WHERE user_login='admin';");
        if(empty($u)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                sprintf(__('Пользователя <strong>"%s"</strong> (с правами администратора), не было найдено',WpsSettings::TEXT_DOMAIN), 'admin'),
                sprintf(__('<p>Одна из хорошо известных и опасных WordPress уязвимостей безопасности Перечень пользователя, в котором Злоумышленник может перечислить действующий счет WordPress пользователя, чтобы запустить перебором против него.
                            Для того, чтобы помочь удержать этот тип атаки, важно,  не иметь значения по умолчанию <a href="%s" target="%s">WordPress администратор</a>
                            имя пользователя включен в вашем блоге.</p>',WpsSettings::TEXT_DOMAIN), 'http://www.acunetix.com/blog/web-security-zone/articles/default-wordpress-administrator-account/', '_blank')
            );
        }
        else {
            // check to see if this user is an administrator
            $userRole = $wpdb->get_var("SELECT meta_value FROM ".$wpdb->usermeta. " WHERE user_id = $u AND meta_key = '".$wpdb->prefix."user_level'");
            if(! empty($userRole)){
                $userRole = intval($userRole);
                if(in_array($userRole, array(8,9,10))){
                    self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                        sprintf(__('Пользователь по умолчанию <strong>"%s"</strong> был найден',WpsSettings::TEXT_DOMAIN), 'admin'),
                        sprintf(__('<p>Одна из хорошо известных и опасных уязвимостей WordPress безопасности Перечень Пользователь, в которой злоумышленник может подобрать пароль к WordPress пользователю путем запуска программы подбора паролей.</p>
                            <p>Для того, чтобы предотвратить этот тип атаки, вы должны изменить настройки по умолчанию <a href="%s" target="%s">WordPress администратор</a> имя пользователя на что-то более трудно угадываемое,.</p>',WpsSettings::TEXT_DOMAIN), 'http://www.acunetix.com/blog/web-security-zone/articles/default-wordpress-administrator-account/', '_blank'),
                        // solution
                        __('<p>Не делайте следующее изменение, если вы не умеете работать с PHPMyAdmin и MySQL. Если нет, попросите кого-то, кто знаком с WordPress и MySQL, чтобы помочь вам. </p>
                            <p>Кроме того, это имеет первостепенное значение для резервного копирования весь ваш блог - в том числе базы данных - прежде, чем сделать какой-либо из изменений, описанных ниже.</p>
                            <p>Чтобы изменить WordPress администратора по умолчанию имя пользователя, перейдите на веб-хоста MySQL Administration Tool (вероятно PHPMyAdmin) и перейдите к вашей базе данных WordPress. Найдите таблицу пользователей, в котором вы найдете столбец user_login. Один из рядов будет содержать администратора в этой области. Измените это к сложным и трудно угадать имя, которое идеально состоит из буквенно-цифровых символов.</p>
                            <p><strong>IMPORTANT:</strong> Даже если имя пользователя трудно догадаться, вам все равно нужен очень сильный пароль.</p>',WpsSettings::TEXT_DOMAIN));
                    return;
                }
            }
        }
    }

    // type: overwrite
    public static function check_tablePrefix()
    {
        global $wpdb, $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['check_table_prefix']['name'];
        $alertType = $wpsPluginAlertsArray['check_table_prefix']['type'];

        if(strcasecmp('wp_', $wpdb->prefix)==0){
            self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                sprintf(__('По умолчанию используется префикс базы данных WordPress (<strong>%s</strong>)',WpsSettings::TEXT_DOMAIN), $wpdb->prefix),
                __('<p>Большинство зарегистрированных WordPress атак на базы данных были выполнены используя уязвимости SQL-инъекций. По переименованию  таблицы базы данных WordPress. Изменив префикс таблиц вы защищаете свой блог на WordPress и веб-сайт от инъекции SQL и атак.</p>
                    <p>Поэтому путем переименования таблиц базы данных WordPress префиксы, Вы автоматически соблюдения вашей безопасности базы данных WordPress против таких опасных атак потому что злоумышленник не сможет угадать имена таблиц.</p>
                    <p>Мы рекомендуем использовать трудно догадаться префиксы, как долго случайных строк, которые включают буквы и цифры.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически <a href="%s">сделать это</a> для вас, но если вы хотите сделать это вручную, то, пожалуйста, прочитайте эту <a href="%s" target="%s">статью</a></p>',WpsSettings::TEXT_DOMAIN),
                        'admin.php?page=wps_database',
                        'http://www.websitedefender.com/wordpress-security/change-wordpress-database-prefix/', '_blank')
            );
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('WordPress префикс базы данных по умолчанию не используется',WpsSettings::TEXT_DOMAIN),
                __('<p>Большинство зарегистрированных WordPress атак базы данных были выполнены используя уязвимости SQL-инъекций. По переименования таблицы базы данных префиксов WordPress вы защищаете свой блог WordPress и веб-сайт от инъекции SQL  и атак.</p>
                    <p>Поэтому путем переименования таблиц базы данных WordPress префиксы, Вы автоматически соблюдения вашей безопасности базы данных WordPress против таких опасных атак, потому что атакующий не сможет угадать имена таблиц.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }
    }

    // type: overwrite
    public static function check_currentVersion()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['check_wp_current_version']['name'];
        $alertType = $wpsPluginAlertsArray['check_wp_current_version']['type'];

        $c = get_site_transient('update_core');
        if(is_object($c))
        {
            if(empty($c->updates)) {
                self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                    __('Вы должны установить последнюю версию WordPress installed',WpsSettings::TEXT_DOMAIN),
                    __('<p>Последняя версия WordPress, как правило, более стабильна и безопасна, и только выпущена для того чтобы включить новые функции или исправить технические ошибки и WordPress безопасность.<p>
                        <p>Использование старой версии WordPress может предоставлять риск вашей безопасности блога, позволяя хакеру использовать известные уязвимости для конкретной версии и получить полный контроль на веб-сервере.</p>',WpsSettings::TEXT_DOMAIN)
                );
            }
            else {
                if (!empty($c->updates[0]))
                {
                    $c = $c->updates[0];
                    if (!isset($c->response) || 'latest' == $c->response ) {
                        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                            __('Вы должны установить последнюю версию WordPress installed',WpsSettings::TEXT_DOMAIN),
                            __('<p>Последняя версия WordPress, как правило, более стабильна и безопасна, и только выпущена для того чтобы включить новые функции или исправить технические ошибки и WordPress безопасность.<p>
                        <p>Использование старой версии WordPress может предоставлять риск вашей безопасности блога, позволяя хакеру использовать известные уязвимости для конкретной версии и получить полный контроль на веб-сервере.</p>',WpsSettings::TEXT_DOMAIN)
                        );
                    }
                    elseif ('upgrade' == $c->response) {
                        self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                            sprintf(__('An updated version of WordPress is available: <strong>%s</strong>',WpsSettings::TEXT_DOMAIN), $c->current),
                            __('<p>Последняя версия WordPress, как правило, более стабильна и безопасна, и только выпущена для того чтобы включить новые функции или исправить технические ошибки и WordPress безопасность<p>
                                <p>Использование старой версии WordPress может предоставлять риск вашей безопасности блога, позволяя хакеру использовать известные уязвимости для конкретной версии и получить полный контроль на веб-сервере.</p>',WpsSettings::TEXT_DOMAIN),
                            sprintf(__('<p>Рекомендуется обновить вашу установку WordPress, как только возможно. Более подробная информация по обновлению WordPress вручную и автоматически можно найти на официальном <a href="%s" target="%s">сайте WordPress</a>.</p>',WpsSettings::TEXT_DOMAIN), 'http://codex.wordpress.org/Updating_WordPress', '_blank')
                        );
                    }
                }
            }
        }
    }

    // type: overwrite
    public static function check_files()
    {
        global $wpsPluginAlertsArray;

        $actionName = $wpsPluginAlertsArray['check_index_wp_content']['name'];
        $alertType = $wpsPluginAlertsArray['check_index_wp_content']['type'];
        $path = WP_CONTENT_DIR.'/index.php';
        if(!is_file($path)) {
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                sprintf(__('Файл <strong>"%s"</strong> не был найден в <strong>"%s"</strong> directory',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content'),
                __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                    <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически создать пустой <strong>"%s"</strong> в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads Если опция <strong>"%s"</strong> включена на странице настроек плагина.</p>',WpsSettings::TEXT_DOMAIN),
                            'index.php', 'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг директорий')
            );
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                sprintf(__('Файл <strong>"%s"</strong> был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content'),
                __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                    <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }

        $actionName = $wpsPluginAlertsArray['check_index_wp_plugins']['name'];
        $alertType = $wpsPluginAlertsArray['check_index_wp_plugins']['type'];
        $path = WP_CONTENT_DIR.'/plugins/index.php';
        if(!is_file($path)) {
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                sprintf(__('Файл <strong>"%s"</strong> не был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content/plugins'),
                __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                    <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически создать пустой <strong>"%s"</strong> в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads if
                            the option <strong>"%s"</strong> включена на странице настроек плагина.</p>',WpsSettings::TEXT_DOMAIN),
                        'index.php', 'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг директорий')
            );
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                sprintf(__('Файл <strong>"%s"</strong> файл был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content/plugins'),
                __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                    <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }

        $actionName = $wpsPluginAlertsArray['check_index_wp_themes']['name'];
        $alertType = $wpsPluginAlertsArray['check_index_wp_themes']['type'];
        $path = WP_CONTENT_DIR.'/themes/index.php';
        if(!is_file($path)) {
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                sprintf(__('Файл <strong>"%s"</strong> не был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content/themes'),
                __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                    <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически создать пустой <strong>"%s"</strong> в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads if
                            the option <strong>"%s"</strong> включена на странице настроек плагина.</p>',WpsSettings::TEXT_DOMAIN),
                            'index.php', 'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг директорий')
            );
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                sprintf(__('Файл <strong>"%s"</strong> файл был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content/themes'),
                __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                    <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }

        $actionName = $wpsPluginAlertsArray['check_index_wp_uploads']['name'];
        $alertType = $wpsPluginAlertsArray['check_index_wp_uploads']['type'];
        $path = WP_CONTENT_DIR.'/uploads';
        if(is_dir($path))
        {
            if(!is_file(WP_CONTENT_DIR.'/uploads/index.php')) {
                self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                    sprintf(__('Файл <strong>"%s"</strong> не был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content/uploads'),
                    __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                        <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN),
                    sprintf(__('<p>Этот плагин может автоматически создать пустой <strong>"%s"</strong> в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads if the
                        option <strong>"%s"</strong> включена на странице настроек плагина.</p>',WpsSettings::TEXT_DOMAIN),
                        'index.php', 'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг директорий')
                );
            }
            else {
                self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                    sprintf(__('Файл <strong>"%s"</strong> файл был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'index.php', '/wp-content/uploads'),
                    __('<p>Перечень каталогов предоставляет злоумышленнику полный индекс всех ресурсов, находящихся внутри каталога. Конкретные риски и последствия варьируются в зависимости от файлов, которые перечислены и доступны.</p>
                    <p>Таким образом, важно, чтобы защитить ваши каталоги, зоздайте в них пустой файл index.php или index.htm в нутри них.</p>',WpsSettings::TEXT_DOMAIN)
                );
            }
        }

        $actionName = $wpsPluginAlertsArray['check_htaccess_wp_admin']['name'];
        $alertType = $wpsPluginAlertsArray['check_htaccess_wp_admin']['type'];
        $path = ABSPATH.'wp-admin/.htaccess';
        if(!is_file($path)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                sprintf(__('Файл <strong>"%s"</strong> не был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), '.htaccess', 'wp-admin'),
                __('<p>.htaccess файл конфигурации, который обеспечивает возможность задавать параметры конфигурации для конкретного каталога на веб-сайте.
                    Файл .htaccess может включать в себя один или несколько параметров конфигурации, которые применяются только для каталога, в котором помещен файл .htaccess.
                    Таким образом, хотя веб-серверы имеют свои собственные файлы настроек основной конфигурации, файл .htaccess может быть использован, чтобы переопределить их основные параметры конфигурации.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Пожалуйста, обратитесь к этой <a href="%s" target="%s">статье</a> для получения дополнительной информации о том, как создать файл .htaccess.</p>',WpsSettings::TEXT_DOMAIN),
                    'http://www.acunetix.com/blog/web-security-zone/articles/what-is-an-htaccess-file/', '_blank')
            );
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                sprintf(__('Файл <strong>"%s"</strong> файл был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), '.htaccess', 'wp-admin'),
                __('<p>.htaccess файл конфигурации, который обеспечивает возможность задавать параметры конфигурации для конкретного каталога на веб-сайте.
                    Файл .htaccess может включать в себя один или несколько параметров конфигурации, которые применяются только для каталога, в котором помещен файл .htaccess.
                    Таким образом, хотя веб-серверы имеют свои собственные файлы настроек основной конфигурации, файл .htaccess может быть использован, чтобы переопределить их основные параметры конфигурации.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }

        $actionName = $wpsPluginAlertsArray['check_readme_wp_root']['name'];
        $alertType = $wpsPluginAlertsArray['check_readme_wp_root']['type'];
        $path = ABSPATH.'readme.html';
        if(is_file($path))
        {
            if(is_readable($path)){
                $fsize = @filesize($path);
                // couldn't retrieve the file's size
                if($fsize > 0){
                    self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                        __('Файл <strong>readme.html</strong> был найден в директории root',WpsSettings::TEXT_DOMAIN),
                        __('<p>Установка WordPress по умолчанию содержит файл readme.html.
                                Этот файл представляет собой простой HTML-файл, который не содержит исполняемый контент, который может быть использован хакерами или злоумышленниками. Тем не менее, этот файл может предоставить хакерам версию вашей установки WordPress, поэтому его желательно либо удалить, либо сделать его недоступным для посетителей.</p>',WpsSettings::TEXT_DOMAIN),
                        sprintf(__('<p>Этот плагин может автоматически удалить его содержание если опция <strong>"%s"</strong> включена на странице настроек плагина.
                                Вы также можете удалить этот файл вручную при подключении к веб-сайт через FTP соединение.</p>',WpsSettings::TEXT_DOMAIN), 'Освободите содержимое файла readme.html из корневого каталога.')
                    );
                }
                else {
                    self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                        __('Файл <strong>readme.html</strong> либо пуст, либо не доступен.',WpsSettings::TEXT_DOMAIN),
                        __('<p>Установка WordPress по умолчанию содержит файл readme.html file.
                                Этот файл представляет собой простой HTML-файл, который не содержит исполняемый контент, который может быть использована хакерами или злоумышленниками.
                                Тем не менее, этот файл может предоставить хакерам информацию о версии вашей установки WordPress, поэтому желательно либо удалить его, либо сделать его недоступным для посетителей.</p>',WpsSettings::TEXT_DOMAIN)
                    );
                }
            }
            else {
                self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                    __('Файл <strong>readme.html</strong> file is not accessible.',WpsSettings::TEXT_DOMAIN),
                    __('<p>Установка WordPress по умолчанию содержит файл readme.html file.
                            Этот файл представляет собой простой HTML-файл, который не содержит исполняемый контент, который может быть использована хакерами или злоумышленниками.
                            Тем не менее, этот файл может предоставить хакерам информацию о версии вашей установки WordPress, поэтому желательно либо удалить его, либо сделать его недоступным для посетителей.</p>',WpsSettings::TEXT_DOMAIN)
                );
            }
        }
        else{
            // file not found or file is not accessible
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('Файл <strong>readme.html</strong> не был найден в root directory',WpsSettings::TEXT_DOMAIN),
                __('<p>Установка WordPress по умолчанию содержит файл readme.html file.
                        Этот файл представляет собой простой HTML-файл, который не содержит исполняемый контент, который может быть использована хакерами или злоумышленниками.
                        Тем не менее, этот файл может предоставить хакерам информацию о версии вашей установки WordPress, поэтому желательно либо удалить его, либо сделать его недоступным для посетителей.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }
    }

    //type: overwrite
    //@since v4.0.2
    static function check_adminInstallFile()
    {
        global $wpsPluginAlertsArray;

        $actionName = $wpsPluginAlertsArray['check_wp_admin_install']['name'];
        $alertType = $wpsPluginAlertsArray['check_wp_admin_install']['type'];
        $path = ABSPATH.'wp-admin/install.php';
        if(is_file($path)) {
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                sprintf(__('Файл <strong>"%s"</strong> был найден в <strong>"%s"</strong> директории',WpsSettings::TEXT_DOMAIN), 'install.php', '/wp-admin'),
                __('<p>Файл install.php необходим для того, что бы установить WordPress и после его установки, желательно ограничить доступ к нему или удалить его.</p>',WpsSettings::TEXT_DOMAIN),
                __('<p>Изменение прав файлов 000 <strong>chmod(000)</strong> или удалить его из директории <strong>/wp-admin</strong></p>',WpsSettings::TEXT_DOMAIN)
            );
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                sprintf(__('Файл <strong>"%s"</strong> не был найден в директории <strong>"%s"</strong>',WpsSettings::TEXT_DOMAIN), 'install.php', '/wp-admin'),
                __('<p>Файл install.php необходим для того, что бы установить WordPress и после его установки, желательно ограничить доступ к нему или удалить его.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }
    }
    //type: overwrite
    //@since v4.0.2
    static function check_adminUpgradeFile()
    {
        global $wpsPluginAlertsArray;

        $actionName = $wpsPluginAlertsArray['check_wp_admin_upgrade']['name'];
        $alertType = $wpsPluginAlertsArray['check_wp_admin_upgrade']['type'];
        $path = ABSPATH.'wp-admin/upgrade.php';
        if(is_file($path)) {
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                sprintf(__('Файл <strong>"%s"</strong> был найден в директории <strong>"%s"</strong>',WpsSettings::TEXT_DOMAIN), 'upgrade.php', '/wp-admin'),
                __('<p>Файл Upgrade.php необходим для обновления WordPress, так же это небольшая уязвимость и желательно ограничить доступ к нему или удалить его вовсе.</p>',WpsSettings::TEXT_DOMAIN),
                __('<p>Изменение прав файлов 000 <strong>chmod(000)</strong> или удалить его из директории <strong>/wp-admin</strong></p>',WpsSettings::TEXT_DOMAIN)
            );
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                sprintf(__('Файл <strong>"%s"</strong> файл был найден в директории <strong>"%s"</strong>',WpsSettings::TEXT_DOMAIN), 'upgrade.php', '/wp-admin'),
                __('<p>Файл Upgrade.php необходим для обновления WordPress, так же это небольшая уязвимость и желательно ограничить доступ к нему или удалить его вовсе.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }
    }
}