<?php
/**
 * Class WsdInfo
 * Static class. Provides common methods to inspect a WordPress installation settings
 */
class WsdInfo
{
    public static function getCurrentVersionInfo()
    {
        $c = get_site_transient( 'update_core' );
        if ( is_object($c))
        {
            if (empty($c->updates))
            {
                return '<span class="acx-icon-alert-success">'.__('Вы должны установить последнюю версию WordPress.',WpsSettings::TEXT_DOMAIN).'</span>';
            }

            if (!empty($c->updates[0]))
            {
                $c = $c->updates[0];

                if ( !isset($c->response) || 'latest' == $c->response ) {
                    return '<span class="acx-icon-alert-success">'.__('Вы должны установить последнюю версию WordPress.',WpsSettings::TEXT_DOMAIN).'</span>';
                }

                if ('upgrade' == $c->response)
                {
                    $lv = $c->current;
                    $m = '<span class="acx-icon-alert-critical">'.sprintf(__('Новая версия WordPress <strong>(%s)</strong> доступна. Вы должны обновить до последней версии.',WpsSettings::TEXT_DOMAIN), $lv).'</span>';
                    return __($m);
                }
            }
        }
        return '<span class="acx-icon-alert-critical">'.__('Произошла ошибка при попытке получить статус вашей версии WordPress.',WpsSettings::TEXT_DOMAIN).'</span>';
    }

    public static function getDatabasePrefixInfo()
    {
        global $table_prefix;
        if (strcasecmp('wp_', $table_prefix)==0) {
            return '<span class="acx-icon-alert-critical">'
            .__('Ваш префикс базы данных не должен быть <code>wp_</code>.',WpsSettings::TEXT_DOMAIN)
            .'(<a href="http://www.websitedefender.com/wordpress-security/wordpress-database-tables-prefix/" target="_blank">'.__('подробнее',WpsSettings::TEXT_DOMAIN).'</a>)</span>';
        }
        return '<span class="acx-icon-alert-success">'.__('Ваш префикс базы данных не <code>wp_</code>.',WpsSettings::TEXT_DOMAIN).'</span>';
    }

    public static function getWpVersionStatusInfo()
    {
        if (WsdSecurity::$isVersionHidden) {
            return '<span class="acx-icon-alert-success">'.__('Версия WordPress <code>скрыта</code> для всех пользователей, кроме администраторов',WpsSettings::TEXT_DOMAIN).'</span>';
        }
    }

    public static function getPhpStartupErrorStatusInfo()
    {
        $dse = strtolower(ini_get('display_startup_errors'));
        if ($dse == 0) {
            return '<span class="acx-icon-alert-success">'.__('Ошибки запуска <code>не</code> отображаются.',WpsSettings::TEXT_DOMAIN).'</span><br/>';
        }
        return '<span class="acx-icon-alert-critical">'.__('Ошибки запуска <code>отображаются</code>.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
    }

    public static function getAdminUsernameInfo()
    {
        global $wpdb;
        $u = $wpdb->get_var("SELECT `ID` FROM $wpdb->users WHERE user_login='admin';");
        if (empty($u)) {
            return '<span class="acx-icon-alert-success">'.__('Пользователь <code>admin</code> не найден.',WpsSettings::TEXT_DOMAIN).'</span>';
        }
        return '<span class="acx-icon-alert-critical">'.__('Пользователь <code>admin</code> найден! Вы должны изменить его для того, чтобы избежать атак перечисления пользователем.',WpsSettings::TEXT_DOMAIN).'</span>';
    }

    public static function getWpAdminHtaccessInfo()
    {
        $file = trailingslashit(ABSPATH).'wp-admin/.htaccess';
        if (is_file($file)) {
            return '<span class="acx-icon-alert-success">'.__('<code>.htaccess</code> файл был найден в каталоге <code>wp-admin</code>.',WpsSettings::TEXT_DOMAIN).'</span>';
        }
        return '<span class="acx-icon-alert-info">'
        .__('<code>.htaccess</code> файл не найден в каталоге <code>wp-admin</code>.',WpsSettings::TEXT_DOMAIN)
        .'(<a href="http://www.websitedefender.com/wordpress-security/htaccess-files-wordpress-security/" target="_blank">'.__('подробнее',WpsSettings::TEXT_DOMAIN).'</a>)</span>';
    }

    public static function getDatabaseUserAccessRightsInfo()
    {
        $rights = WsdInfoServer::getDatabaseUserAccessRights();
        $rightsNeeded = $rights['rightsNeeded'];
        $rightsHaving = $rights['rightsHaving'];
        $rightsMissing = array_diff($rightsNeeded, $rightsHaving);

        if ($rights['rightsTooMuch']) {
            $e = '<code>'.implode('</code>, <code>', $rightsNeeded).'</code>';
            $m = sprintf(__("На данный момент у пользователя настроен доступ к базе данных WordPress <code>имеет слишком много прав</code>.
                Мы советуем ограничить его права (только %s) или использовать другого пользователя с более ограниченными правами для того, чтобы повысить безопасность вашего сайта.",WpsSettings::TEXT_DOMAIN),$e);
            return '<span class="acx-icon-alert-info">'.$m.'</span>';
        }
        else
        {
            if($rights['rightsEnough']){
                $m = __("На данный момент у пользователя настроен доступ к базе данных WordPress имеет соответствующие права, чтобы взаимодействовать с базой данных.",WpsSettings::TEXT_DOMAIN);
                return '<span class="acx-icon-alert-success">'.$m.'</span>';
            }
            else {
                $missing = '<code>'.implode('</code>, <code>', $rightsMissing).'</code>';
                $m = sprintf(__("На данный момент у пользователя настроен доступ к базе данных WordPress отсутствуют следующие права, чтобы взаимодействовать с базой данных: %s",WpsSettings::TEXT_DOMAIN),$missing);
                return '<span class="acx-icon-alert-info">'.$m.'</span>';
            }
        }
    }

    public static function getWpContentIndexInfo()
    {
        if (is_file(trailingslashit(WP_CONTENT_DIR).'index.php')) {
            return '<span class="acx-icon-alert-success">'.__('Файл <code>index.php найден</code> в каталоге wp-content.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
        }
        return '<span class="acx-icon-alert-info">'.__('Файл <code>index.php не найден</code> в каталоге wp-content! Вы должны создать в целях предотвращения просмотра каталога.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
    }

    public static function getWpContentPluginsIndexInfo()
    {
        $dirPath = trailingslashit(WP_CONTENT_DIR).'plugins/';
        if(!is_dir($dirPath)) { return ''; }
        if (is_file($dirPath.'index.php')) {
            return '<span class="acx-icon-alert-success">'.__('Файл <code>index.php найден</code> в каталоге wp-content.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
        }
        return '<span class="acx-icon-alert-info">'.__('Файл <code>index.php не найден</code> в каталоге wp-content! Вы должны создать в целях предотвращения просмотра каталога.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
    }

    public static function getWpContentThemesIndexInfo()
    {
        $dirPath = trailingslashit(WP_CONTENT_DIR).'themes/';
        if(!is_dir($dirPath)) { return ''; }
        if (is_file($dirPath.'index.php')) {
            return '<span class="acx-icon-alert-success">'.__('Файл <code>index.php найден</code> в каталоге тем.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
        }
        return '<span class="acx-icon-alert-info">'.__('Файл <code>index.php не найден</code> в каталоге тем! Вы должны создать в целях предотвращения просмотра каталога.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
    }

    public static function getWpContentUploadsIndexInfo()
    {
        $dirPath = trailingslashit(WP_CONTENT_DIR).'uploads/';
        if(!is_dir($dirPath)) { return ''; }
        if (is_file($dirPath.'index.php')) {
            return '<span class="acx-icon-alert-success">'.__('Файл <code>index.php найден</code> в папке для закачанных файлов.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
        }
        return '<span class="acx-icon-alert-info">'.__('Файл <code>index.php не найден</code> в папке для закачанных файлов! Вы должны создать в целях предотвращения просмотра каталога.',WpsSettings::TEXT_DOMAIN).'</span>'.'<br/>';
    }

}

class WsdInfoServer extends WsdInfo
{
    public static function getServerInfo()
    {
        global $wpdb;
        $sqlversion = $wpdb->get_var("SELECT VERSION() AS version");
        $mysqlinfo = $wpdb->get_results("SHOW VARIABLES LIKE 'sql_mode'");
        if (is_array($mysqlinfo)) $sql_mode = $mysqlinfo[0]->Value;
        if (empty($sql_mode)) $sql_mode = __('Not set',WpsSettings::TEXT_DOMAIN);
        $sm = ini_get('safe_mode');
        if (strcasecmp('On', $sm) == 0) { $safe_mode = __('On',WpsSettings::TEXT_DOMAIN); }
        else { $safe_mode = __('Off',WpsSettings::TEXT_DOMAIN); }
        if(ini_get('allow_url_fopen')) $allow_url_fopen = __('On',WpsSettings::TEXT_DOMAIN);
        else $allow_url_fopen = __('Off',WpsSettings::TEXT_DOMAIN);
        if(ini_get('upload_max_filesize')) $upload_max = ini_get('upload_max_filesize');
        else $upload_max = __('N/A',WpsSettings::TEXT_DOMAIN);
        if(ini_get('post_max_size')) $post_max = ini_get('post_max_size');
        else $post_max = __('N/A',WpsSettings::TEXT_DOMAIN);
        if(ini_get('max_execution_time')) $max_execute = ini_get('max_execution_time');
        else $max_execute = __('N/A',WpsSettings::TEXT_DOMAIN);
        if(ini_get('memory_limit')) $memory_limit = ini_get('memory_limit');
        else $memory_limit = __('N/A',WpsSettings::TEXT_DOMAIN);
        if (function_exists('memory_get_usage')) $memory_usage = round(memory_get_usage() / 1024 / 1024, 2) . __(' MByte',WpsSettings::TEXT_DOMAIN);
        else $memory_usage = __('N/A',WpsSettings::TEXT_DOMAIN);
        if (is_callable('exif_read_data')) $exif = __('Yes',WpsSettings::TEXT_DOMAIN). " ( V" . substr(phpversion('exif'),0,4) . ")" ;
        else $exif = __('No',WpsSettings::TEXT_DOMAIN);
        if (is_callable('iptcparse')) $iptc = __('Yes',WpsSettings::TEXT_DOMAIN);
        else $iptc = __('No',WpsSettings::TEXT_DOMAIN);
        if (is_callable('xml_parser_create')) $xml = __('Yes',WpsSettings::TEXT_DOMAIN);
        else $xml = __('No',WpsSettings::TEXT_DOMAIN);

        $sqlModeText = __('Режим SQL (sql_mode) является системной переменной MySQL. С помощью этой переменной контролируется режим сервера MySQL SQL.
             Многие эксплуатационные характеристики MySQL сервера могут быть настроены путем установки режима SQL.
             Установив режим SQL надлежащим образом, клиентская программа может поручить доступ к серверу, и включать или отключать поведения, относящиеся к стандартным SQL соответствиям, или предоставить лучшую совместимость с другими системами баз данных. По умолчанию, сервер использует значение sql_mode, который не позволяет никаких ограничений. Таким образом, сервер работает в нестрогом режиме по умолчанию. В нестрогом режиме, сервер MySQL преобразует входные ошибочные значения до ближайшего допустимого значения (как определено из определений столбцов) и продолжает на своем пути.',WpsSettings::TEXT_DOMAIN);
        $phpSafeModeText = __('В PHP в безопасном режиме (параметр safe_mode) - это попытка решения проблемы безопасности на совместно используемых серверах.
Это архитектурно некорректно пытаться решить эту проблему на уровне РНР, но так как альтернатив на веб-сервер и ОС уровни архитектур очень реазны, многие люди, используют безопасный режим.',WpsSettings::TEXT_DOMAIN);
        $phpAllowFopenText = __('PHP allow_url_fopen вариант, если включен (позволяет PHP файлы функции - такие, как \'file_get_contents()\' , \'include\' и \'require\'), может извлекать данные из удаленных местах, как в FTP или веб-сайт, который может представлять риск для безопасности.',WpsSettings::TEXT_DOMAIN);
        $phpMemoryLimitText = __('Парметр PHP memory_limit устанавливает максимальный объем памяти в байтах, который разрешается использовать скрипту.
             При включении memory_limit вы можете защитить ваши приложения от определенных видов атак отказа в обслуживании, а также от ошибок в
             приложения (например, бесконечные циклы, слабое использование изображения на основе функций, или другой памяти интенсивных ошибок).',WpsSettings::TEXT_DOMAIN);
        $phpMaxUploadSizeText = __('Параметр PHP upload_max_filesize ограничивает максимальный размер файлов, которые можно принимать PHP через загрузчик. Злоумышленники могут попытаться отправить грубо больших файлов, чтобы исчерпать ресурсы системы;
             установив реальной стоимости здесь вы можете смягчить некоторые повреждения теми атак.',WpsSettings::TEXT_DOMAIN);
        $phpMaxPostSizeText = __('Опция post_max_size PHP ограничивает максимальный размер запроса POST, который будет обрабатывать PHP. Злоумышленники могут попытаться отправить негабаритных грубо запросы POST, чтобы исчерпать ресурсы системы;
             установив реальной стоимости здесь вы можете смягчить некоторые повреждения теми атак.',WpsSettings::TEXT_DOMAIN);
        $phpScriptExecTimeText = __('Опция max_execution_time PHP устанавливает максимальное время в секундах, сценарий разрешено запускать до того, как прекращается анализатором.
             Это помогает предотвратить плохо написанные скрипты от связывания сервера.',WpsSettings::TEXT_DOMAIN);
        $exifText = __('PHP Exif расширение позволяет работать с изображением мета данных. Например, вы можете использовать EXIF функции для чтения метаданных снимков, сделанных с цифровых камер, работая с
             Информация, хранящаяся в заголовках JPEG и TIFF изображений.',WpsSettings::TEXT_DOMAIN);
        $iptcText = __('Данные IPTC является способ хранения текстовой информации в изображениях определенных Международным советом Пресс телекоммуникациях.
             Она была разработана для фотокорреспондентов, которые должны приложить информацию к изображениям, когда они, представивших их в электронном виде, но это полезно для всех фотографов.
             Это обеспечивает стандартный способ хранения информации, такие как заголовки, ключевые слова, места. Поскольку информация хранится в изображении стандартным способом эту информацию
             может быть доступна для других приложений, поддерживающих IPTC.',WpsSettings::TEXT_DOMAIN);
        $xmlText = __('XML (Extensible Markup Language) это формат данных для структурированного обмена документами в Сети. Это стандартная определяется World Wide Web Consortium (W3C).',WpsSettings::TEXT_DOMAIN);

        $str = '<script type="text/javascript" src="'. WsdUtil::jsUrl('wsdplugin_glossary_tooltip.js').'"></script>';
        $str .= '<ul class="acx-common-list">';
        $str .= '<li>'. __('Operating System',WpsSettings::TEXT_DOMAIN).' : <strong> '.PHP_OS.'</strong></li>';
        $str .= '<li>'. __('Server',WpsSettings::TEXT_DOMAIN).' : <strong>'.$_SERVER["SERVER_SOFTWARE"].'</strong></li>';
        $str .= '<li>'. __('Memory usage',WpsSettings::TEXT_DOMAIN).' : <strong>'.$memory_usage.'</strong></li>';
        $str .= '<li>'. __('PHP Version',WpsSettings::TEXT_DOMAIN).' : <strong>'. PHP_VERSION.'</strong></li>';
        $str .= '<li>'. __('MYSQL Version',WpsSettings::TEXT_DOMAIN).' : <strong>'.$sqlversion.'</strong></li>';
        $str .= '</ul>';

        $str .= '<p class="clear" style="margin-top: 7px;"></p>';

        $str .= '<ul class="acx-common-list">';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$sqlModeText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('SQL Mode',WpsSettings::TEXT_DOMAIN).' : <strong>'.$sql_mode.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$phpSafeModeText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP Safe Mode',WpsSettings::TEXT_DOMAIN).' : <strong>'. $safe_mode.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$phpAllowFopenText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP Allow URL fopen',WpsSettings::TEXT_DOMAIN).' : <strong>'. $allow_url_fopen.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$phpMemoryLimitText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP Memory Limit',WpsSettings::TEXT_DOMAIN).' : <strong>'. $memory_limit.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip"onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$phpMaxUploadSizeText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP Max Upload Size',WpsSettings::TEXT_DOMAIN).' : <strong>'. $upload_max.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$phpMaxPostSizeText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP Max Post Size',WpsSettings::TEXT_DOMAIN).' : <strong>'. $post_max.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$phpScriptExecTimeText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP Max Script Execute Time',WpsSettings::TEXT_DOMAIN).' : <strong>'. $max_execute.'s</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$exifText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP Exif support',WpsSettings::TEXT_DOMAIN).' : <strong>'. $exif.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$iptcText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP IPTC support',WpsSettings::TEXT_DOMAIN).' : <strong>'. $iptc.'</strong></li>';
        $str .= '<li class="wsdplugin-tooltip" onmouseover="wsdplugin_glossary_tooltip.show(this);" data-bind-title="'.$xmlText.'" onmouseout="wsdplugin_glossary_tooltip.hide();">'. __('PHP XML support',WpsSettings::TEXT_DOMAIN).' : <strong>'. $xml.'</strong></li>';
        $str .= '</ul>';
        return $str;
    }

    /**
     * @public
     * @static
     * @global $wpdb, DB_USER, DB_HOST
     *
     * Retrieve the rights the current used user to connect to the database server has.
     *
     * @return array  array('rightsEnough' => true|false, 'rightsTooMuch' => true|false, 'rightsMissing' => array, 'rightsNeeded' => array);
     */
    public static function getDatabaseUserAccessRights()
    {
        global $wpdb;

        $rightsNeeded = array('SELECT','INSERT','UPDATE','DELETE','ALTER');
        $data = array(
            'rightsEnough' => false,
            'rightsTooMuch' => false,
            'rightsHaving' => array(),
            'rightsNeeded' => $rightsNeeded
        );

        $rights = $wpdb->get_results("SHOW GRANTS FOR '".DB_USER."'@'".DB_HOST."'", ARRAY_N);

        if (empty($rights)) {
            //return $data;
            $rights = $wpdb->get_results("SHOW GRANTS FOR current_user()", ARRAY_N);
            if(empty($rights)){
                return $data;
            }
        }

        foreach($rights as $_right)
        {
            $right = $_right[0];
            //#! no rights
            if(preg_match("/GRANT USAGE ON/", $right)){
                continue;
            }
            //#! way too many. db scope || global scope
            $right = str_replace('\\','',$right);
            $pattern = "/ALL PRIVILEGES ON `?".preg_quote(DB_NAME)."`?/";
            if(preg_match($pattern, $right) || preg_match("/ALL PRIVILEGES ON \*\./", $right)){
                array_push($rightsNeeded, 'CREATE');
                $data = array(
                    'rightsEnough' => true,
                    'rightsTooMuch' => true,
                    'rightsHaving' => $rightsNeeded,
                    'rightsNeeded' => $rightsNeeded
                );
                break;
            }
            //#! more secure. db scope || global scope
            elseif(preg_match_all("/GRANT (.*) ON `?".preg_quote(DB_NAME)."`?/",$right,$matches) || preg_match_all("/GRANT (.*) ON \*\./",$right,$matches)){
                if(! empty($matches[1][0])){
                    $foundRights = explode(',', $matches[1][0]);
                    $foundRights = array_map("trim", $foundRights);
                    $missingRights = array_diff($rightsNeeded, $foundRights);
                    $data = array(
                        'rightsEnough' => (empty($missingRights) ? true : false),
                        'rightsTooMuch' => false,
                        'rightsHaving' => $foundRights,
                        'rightsNeeded' => $rightsNeeded
                    );
                    break;
                }
            }
        }
        return $data;
    }
}