<?php //if(! defined('WPS_PLUGIN_PREFIX')) return;
/**
 * Class WsdSecurity
 * Static class. Provides security fixes for WordPress
 */

class WsdSecurity extends WsdPlugin
{
    /**
     * The prefix each method should have in order to be executed automatically.
     * @var string Defaults to 'fix_'
     */
    public static $methodPrefix = 'fix_';
    public static $isVersionHidden = false;


    /** Hide WordPress version for all users but administrators */
    public static function fix_hideWpVersion()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_version_hidden']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_version_hidden']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                __('Версия WordPress отображается для всех пользователей',WpsSettings::TEXT_DOMAIN),
                __('<p>Показана версия WordPress в frontend и в бэкэндов интерфейсах для всех посетителей и пользователей вашего сайта , а это риск безопасности, потому что, если хакер знает, на какой версии WordPress работает сайт, то ему легче его вскрыть.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрыть версию WordPress с frontend, backend и RSS-каналы, если опция<strong>"%s"</strong> проверяется на плагином страницу настроек.</p>',WpsSettings::TEXT_DOMAIN),
                        'Скрытие версии WordPress для всех пользователей, кроме администраторов')
            );
            return;
        }

        //@@ back-end
        if(is_admin())
        {
            if(! WsdUtil::isAdministrator()){
                function __hideFooterVersion(){ return ' ';}
                add_filter( 'update_footer', '__hideFooterVersion',800);
            }
            self::$isVersionHidden = true;
            // version hidden
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('WordPress версии отображаются только для пользователей администраторов',WpsSettings::TEXT_DOMAIN),
                __('<p>Отображение версии WordPress на фронтенде и бэкэнде для всех посетителей и пользователей вашего сайта-это риск безопасности, потому что если хакер знает, на какой версии WordPress работает сайт, это может помочь ему повредить ваш сайт.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }
        //@@ front-end
        else {
            if(WsdUtil::isAdministrator()){
                return;
            }
            global $wp_db_version, $manifest_version, $tinymce_version;

            // random values
            $v = intval( rand(0, 9999) );
            $d = intval( rand(9999, 99999) );
            $m = intval( rand(99999, 999999) );
            $t = intval( rand(999999, 9999999) );

            if ( function_exists('the_generator') )
            {
                // eliminate version for wordpress >= 2.4
                remove_filter( 'wp_head', 'wp_generator' );
                $actions = array( 'rss2_head', 'commentsrss2_head', 'rss_head', 'rdf_header', 'atom_head', 'comments_atom_head', 'opml_head', 'app_head' );
                foreach ( $actions as $action ) {
                    remove_action( $action, 'the_generator' );
                }
                // for vars
                $wp_db_version = $d;
                $manifest_version = $m;
                $tinymce_version = $t;
            }
            self::$isVersionHidden = true;

            // version hidden
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('WordPress версии отображается только для пользователей администраторов',WpsSettings::TEXT_DOMAIN),
                __('<p>Отображение версии WordPress на фронтенде и бэкэнде для всех посетителей и пользователей вашего сайта-это риск безопасности, потому что если хакер знает, на какой версии WordPress работает сайт, это может помочь ему повредить ваш сайт.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }
    }

    /** Remove various meta tags generators from the blog's head tag for non-administrators */
    public static function fix_removeWpMetaGeneratorsFrontend()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_generators_frontend']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_generators_frontend']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                __('WordPress Мета теги отображаются в пользовательской части для всех пользователей',WpsSettings::TEXT_DOMAIN),
                __('<p>По умолчанию WordPress создает несколько Мета-тегов, среди которых в настоящее время устанавливаются версии, которые дают хакеру знания о вашей установки WordPress. На данный момент, эти Мета-теги доступны для любого, чтобы видеть, что представляет потенциальную угрозу безопасности.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрывать Мета теги WordPress  по умолчанию, если параметр <strong>"%s"</strong> проверяется на плагин страницу настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить различные Мета теги генераторов из головы блога тег для не-администраторов')
            );
            return;
        }

        if (!is_admin())
        {
            if(!WsdUtil::isAdministrator()){
                //@@ remove various meta tags generators from blog's head tag
                function acx_filter_generator($gen, $type)
                {
                    switch ( $type ) {
                        case 'html':
                            $gen = '<meta name="generator" content="WordPress">';
                            break;
                        case 'xhtml':
                            $gen = '<meta name="generator" content="WordPress" />';
                            break;
                        case 'atom':
                            $gen = '<generator uri="http://wordpress.org/">WordPress</generator>';
                            break;
                        case 'rss2':
                            $gen = '<generator>http://wordpress.org/?v=</generator>';
                            break;
                        case 'rdf':
                            $gen = '<admin:generatorAgent rdf:resource="http://wordpress.org/?v=" />';
                            break;
                        case 'comment':
                            $gen = '<!-- generator="WordPress" -->';
                            break;
                    }
                    return $gen;
                }
                foreach ( array( 'html', 'xhtml', 'atom', 'rss2', 'rdf', 'comment' ) as $type ) {
                    add_filter( "get_the_generator_".$type, 'acx_filter_generator', 10, 2 );
                }
            }
        }
        // version hidden
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('WordPress мета-теги отображаются только на интерфейсе для пользователей администраторов',WpsSettings::TEXT_DOMAIN),
            __('<p>По умолчанию WordPress создает несколько Мета-тегов, среди которых в настоящее время устанавливаются версии, которые дают хакеру знания о вашей установке WordPress.
На данный момент, все Мета теги WordPress по умолчанию скрыты для всех пользователей, кроме администраторов.</p>',WpsSettings::TEXT_DOMAIN)
        );
    }

    /** Remove Really Simple Discovery meta tags from front-end */
    public static function fix_removeReallySimpleDiscovery()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_rsd_frontend']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_rsd_frontend']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('В WordPress очень простое открытие тега отображается в пользовательской части для всех пользователей',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>По умолчанию, WordPress создает <strong> RSD мета-тег </strong>, чтобы блоггеры потреблять услуги, как Flickr с помощью <a href="%s" target="%s">XML-RPC</a> протокола.
                            Если вы не используете такие услуги, рекомендуется, чтобы этот мета-тег скрыть.</p>',WpsSettings::TEXT_DOMAIN),
                        'http://en.wikipedia.org/wiki/XML-RPC', '_blank'),
                sprintf(__('<p>Этот плагин может автоматически скрывать RSD мета-тег, если опция <strong> "%s" </strong> проверяется на плагин страницs настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить действительно просто Дискавери мета-теги из front-end')
            );
            return;
        }

        if (!is_admin()) {
            if(!WsdUtil::isAdministrator() && function_exists('rsd_link')) {
                remove_action('wp_head', 'rsd_link');
            }
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('WordPress действительно простое открытие тег отображается только на интерфейсе для пользователей администраторов.',WpsSettings::TEXT_DOMAIN),
            sprintf(__('<p>По умолчанию, WordPress создает <strong> RSD мета-тег </strong>, чтобы блоггеры потреблять услуги, как Flickr с помощью <a href="%s" target="%s">XML-RPC</a> протокола.
                            Если вы не используете такие услуги, рекомендуется, скрыть этот мета-тег.</p>',WpsSettings::TEXT_DOMAIN),
                'http://en.wikipedia.org/wiki/XML-RPC', '_blank')
        );
    }

    /** Remove Windows Live Writer meta tags from front-end */
    public static function fix_removeWindowsLiveWriter()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_wlw_frontend']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_wlw_frontend']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                __('Вордпресс для Windows Live писатель тег отображается в пользовательской части для всех пользователей',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>По умолчанию WordPress создает wlw Мета-тег, чтобы позволить блогерам публиковать свои статьи, используя <strong>"%s"</strong> приложение.
                        Рекомендуется, чтобы скрыть этот мета тег из всех посетителей. Если опция <strong> "%s" </strong> проверяется на плагины странице настроек, это мета-тег будет доступна для пользователей администраторов использовать <strong>"%s"</strong> приложения публиковать свои сообщения в блоге.</p>',WpsSettings::TEXT_DOMAIN),
                    'Windows Live Writer', 'Удалить Windows Live Writer мета-теги из front-end', 'Windows Live Writer'),
                sprintf(__('<p>Этот плагин может автоматически скрывать WLW мета-тег, если опция <strong>"%s"</strong> проверяется на плагины странице настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить Windows Live Writer мета-теги из front-end"')
            );
            return;
        }

        if (!is_admin() && function_exists('wlwmanifest_link')) {
            if(!WsdUtil::isAdministrator()) {
                remove_action('wp_head', 'wlwmanifest_link');
            }
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('WordPress Windows Live Writer тег отображается только на интерфейсе для пользователей администраторов',WpsSettings::TEXT_DOMAIN),
            sprintf(__('<p>По умолчанию, WordPress создает WLW мета-тег, чтобы блоггеры публикуют свои статьи, используя <strong>"%s"</strong> приложений.
                        Рекомендуется, чтобы скрыть этот мета тег из всех посетителей. Если опция <strong>"%s"</strong> проверяются плагины на странице настроек, это мета-тег будет доступна для пользователей администраторов использовать <strong>"%s"</strong> приложения публиковать свои сообщения в блоге.</p>',WpsSettings::TEXT_DOMAIN),
                'Windows Live Writer', 'Удалить Windows Live Writer мета-теги из front-end', 'Windows Live Writer')
        );
    }

    /** Отключить отчет об ошибках (PHP + DB) для всех, кроме администраторов */
    public static function fix_disableErrorReporting()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_error_reporting']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_error_reporting']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                __('Проверка PHP и базы данных отчет об ошибках отключен',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>По умолчанию, WordPress скрывает ошибки базы данных, но есть случаи, когда плагин может позволить им, таким образом, это очень важно, чтобы этот тип ошибок выключен, так что если есть ошибка во время подключения к базе данных пользователь не получит доступ к сообщение об ошибке генерируется во время этого запроса.</p>
                            <p>Как по поводу ошибки PHP, с <strong>display_error</strong> Директивы конфигурации PHP включен, ненадежных источников может увидеть вся среда веб-приложения сообщения об ошибках, которые содержат конфиденциальную информацию, которая может быть использована для повода новых нападений.</p>
                            <p>Злоумышленники сделают все, чтобы собрать информацию для того, чтобы дизайн их атаки более изощренным способом, чтобы в конечном итоге взломать ваш веб-сайт или веб-приложение, и вызывает отображение ошибок является общей отправной точкой. Сайт ошибки всегда возможны, но они должны быть подавлены отображение спиной к публике.</p>
                            <p>Поэтому мы настоятельно рекомендуем вам иметь <strong>"%s"</strong> возможность проверить плагины на страницу настроек, чтобы обеспечить PHP и базы данных ошибок будет скрыто от пользователей. Для получения более подробной информации, пожалуйста, проверьте следующее <a href="%s" target="%s">статья</a>.</p>',WpsSettings::TEXT_DOMAIN),
                    'Отключить отчет об ошибках (PHP + DB) для всех, кроме администраторов', 'http://www.acunetix.com/blog/web-security-zone/articles/php-security-directive-your-website-is-showing-php-errors/', '_blank'),
                sprintf(__('<p>Этот плагин может делать это автоматически, если опция <strong>"%s"</strong> проверяется плагины на странице настроек.</p>',WpsSettings::TEXT_DOMAIN),
                    'Отключить отчет об ошибках (PHP + DB) для всех, кроме администраторов')
            );
            return;
        }
        if(! WsdUtil::isAdministrator())
        {
            @error_reporting(0);
            @ini_set('display_errors','Off');
            @ini_set('display_startup_errors', 0);
            global $wpdb;
            $wpdb->hide_errors();
            $wpdb->suppress_errors();
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('Сообщения об ошибках, PHP и базы данных, включена только для пользователей администраторов',WpsSettings::TEXT_DOMAIN),
            sprintf(__('<p>По умолчанию, WordPress скрывает ошибки базы данных, но есть случаи, когда плагин может позволить им, таким образом, это очень важно, чтобы этот тип ошибок выключен, так что если есть ошибка во время подключения к базе данных пользователь не получит доступ к сообщение об ошибке генерируется во время этого запроса.</p>
                        <p>Как о ошибки PHP, с <strong>display_error</strong> включен директива конфигурации PHP, ненадежные источники могут видеть подробные веб-приложений сообщения об ошибках среды, которые включают конфиденциальную информацию, которая может быть использована для изготовления новых нападений.</p>
                        <p>Злоумышленники будут делать все, чтобы собрать информацию для того, чтобы разработать свою атаку в более изощренным способом, чтобы в конечном итоге взломать ваш сайт или веб-приложение, и вызывая ошибки на дисплей является общей отправной точкой. Ошибки сайта всегда могут возникнуть, но они должны быть подавлены с отображается обратно к публике.</p>
                        <p>Поэтому мы настоятельно рекомендуем вам иметь <strong> "%" так </strong> возможность проверить плагины на странице настроек, чтобы обеспечить PHP и базы данных ошибок будет скрыто от пользователей. Для получения более подробной информации, пожалуйста, проверьте следующее <a href="%s" target="%s">статья</a>.</p>',WpsSettings::TEXT_DOMAIN),
                'Отключить отчет об ошибках (PHP + DB) для всех, кроме администраторов', 'http://www.acunetix.com/blog/web-security-zone/articles/php-security-directive-your-website-is-showing-php-errors/', '_blank')
        );
    }

    /** Удалить основных уведомления об обновлениях из задней конец для всех, но администраторов */
    public static function fix_removeCoreUpdateNotification()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_core_update_notif']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_core_update_notif']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                __('Основные уведомлениями об обновлении отображается для всех пользователей',WpsSettings::TEXT_DOMAIN),
                __('<p>Эти уведомления отображаются в верхней части экрана по платформе WordPress, когда сайт был обновлен или нуждается в обновлении.</p>
                    <p>Эти уведомления должны рассматриваться только на веб-сайте и администраторы не видно каких-либо других зарегистрированных пользователей с этим веб-сайт.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрывать эти уведомления, если опция <strog>"%s"</strong> проверяется плагин на страницу настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить основных уведомления об обновлениях из задней конец для всех, но администраторов')
            );
            return;
        }

        if (!WsdUtil::isAdministrator())
        {
            add_action( 'admin_init', create_function( '$a', "remove_action( 'admin_notices', 'maintenance_nag' );" ) );
            add_action( 'admin_init', create_function( '$a', "remove_action( 'admin_notices', 'update_nag', 3 );" ) );
            add_action( 'admin_init', create_function( '$a', "remove_action( 'admin_init', '_maybe_update_core' );" ) );
            add_action( 'init', create_function( '$a', "remove_action( 'init', 'wp_version_check' );" ) );
            add_filter( 'pre_option_update_core', create_function( '$a', "return null;" ) );
            remove_action( 'wp_version_check', 'wp_version_check' );
            remove_action( 'admin_init', '_maybe_update_core' );
            add_filter( 'pre_transient_update_core', create_function( '$a', "return null;" ) );
            add_filter( 'pre_site_transient_update_core', create_function( '$a', "return null;" ) );
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('Основные уведомлениями об обновлении отображаются только для пользователей администраторов.',WpsSettings::TEXT_DOMAIN),
            __('<p>Эти уведомления отображаются в верхней части экрана по платформе WordPress, когда сайт был обновлен или нуждается в обновлении.</p>
                <p>В настоящее время, эти уведомления будут отображаться только для пользователей администраторов.</p>',WpsSettings::TEXT_DOMAIN)
        );
    }

    /** Удалить плагины обновления уведомления во back-end */
    public static function fix_removePluginUpdateNotifications()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_plugins_update_notif']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_plugins_update_notif']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                __('Уведомлениями об обновлении Плагины отображаются для всех пользователей',WpsSettings::TEXT_DOMAIN),
                __('<p>Эти уведомления отображаются в верхней части экрана по платформе WordPress, когда необходимо администраторов блог, чтобы быть в курсе доступных обновлений для плагина.</p>
                    <p>Эти уведомления должны рассматриваться только на веб-сайте и администраторы не видно каких-либо других зарегистрированных пользователей с этим веб-сайт.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрывать эти уведомления, если опция <strog>"%s"</strong> проверяется плагин на страницу настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить плагины обновления уведомления во back-end')
            );
            return;
        }

        if (!WsdUtil::isAdministrator())
        {
            add_action( 'admin_init', create_function( '$a', "remove_action( 'admin_init', 'wp_plugin_update_rows' );" ), 2 );
            add_action( 'admin_init', create_function( '$a', "remove_action( 'admin_init', '_maybe_update_plugins' );" ), 2 );
            add_action( 'admin_menu', create_function( '$a', "remove_action( 'load-plugins.php', 'wp_update_plugins' );" ) );
            add_action( 'admin_init', create_function( '$a', "remove_action( 'admin_init', 'wp_update_plugins' );" ), 2 );
            add_action( 'init', create_function( '$a', "remove_action( 'init', 'wp_update_plugins' );" ), 2 );
            add_filter( 'pre_option_update_plugins', create_function( '$a', "return null;" ) );
            remove_action( 'load-plugins.php', 'wp_update_plugins' );
            remove_action( 'load-update.php', 'wp_update_plugins' );
            remove_action( 'admin_init', '_maybe_update_plugins' );
            remove_action( 'wp_update_plugins', 'wp_update_plugins' );
            remove_action( 'load-update-core.php', 'wp_update_plugins' );
            add_filter( 'pre_transient_update_plugins', create_function( '$a', "return null;" ) );
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('Плагины уведомления изменение отображаются только для пользователей администраторов',WpsSettings::TEXT_DOMAIN),
            __('<p>В настоящее время, эти уведомления будут отображаться только для пользователей администраторов.</p>',WpsSettings::TEXT_DOMAIN)
        );
    }

    /** Удалить уведомления об обновлениях тем во back-end */
    public static function fix_removeThemeUpdateNotifications()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_themes_update_notif']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_themes_update_notif']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('Уведомлениями об обновлении Темы отображаются для всех пользователей.',WpsSettings::TEXT_DOMAIN),
                __('<p>Эти уведомления отображаются в верхней части экрана по платформе WordPress, когда необходимо администраторов блог, чтобы быть в курсе доступных обновлений для темы.</p>
                    <p>Эти уведомления должны рассматриваться только на веб-сайте и администраторы не видно каких-либо других зарегистрированных пользователей с этим веб-сайт.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрывать эти уведомления, если опция <strog>"%s"</strong> проверяется плагин на страницу настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить уведомления об обновлениях тем во back-end')
            );
            return;
        }

        if (!WsdUtil::isAdministrator())
        {
            remove_action( 'load-themes.php', 'wp_update_themes' );
            remove_action( 'load-update.php', 'wp_update_themes' );
            remove_action( 'admin_init', '_maybe_update_themes' );
            remove_action( 'wp_update_themes', 'wp_update_themes' );
            remove_action( 'load-update-core.php', 'wp_update_themes' );
            add_filter( 'pre_transient_update_themes', create_function( '$a', "return null;" ) );
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('Уведомлениями об обновлении Темы отображаются только для пользователей администраторов',WpsSettings::TEXT_DOMAIN),
            __('<p>В настоящее время, эти уведомления будут отображаться только для пользователей администраторов.</p>',WpsSettings::TEXT_DOMAIN)
        );
    }

    /** Удалить логин уведомления об ошибках во front-end */
    public static function fix_removeLoginErrorNotificationsFrontEnd()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_login_errors']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_login_errors']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                __('WordPress логин ошибок отображаются.',WpsSettings::TEXT_DOMAIN),
                __('<p>Каждый раз, когда неудачные встречаются, платформы WordPress генерирует сообщение об ошибке, отображаемое пользователю.
                        Это потенциальный риск безопасности, потому что он позволяет пользователь знают о своей ошибке (будь то неправильно имя пользователя или пароль), таким образом, сделать свой сайт WordPress более уязвимы для атак.</p>
                    <p>Мы настоятельно рекомендуем вам, чтобы скрыть эти сообщения об ошибках Войти от всех пользователей, чтобы обеспечить более высокий уровень безопасности вашего блога.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрывать эти уведомления, если опция <strog>"%s"</strong> проверяется плагин на страницу настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить логин уведомления об ошибках во front-end')
            );
            return;
        }
        $str = '<link rel="stylesheet" type="text/css" href="'.WsdUtil::cssUrl('acx-styles-extra.css').'"/>';
        add_action('login_head', create_function('$a', "echo '{$str}';"));
        add_filter('login_errors', create_function('$a', "return null;"));
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('WordPress ошибки входа не отображаются.',WpsSettings::TEXT_DOMAIN),
            __('<p>В настоящее время эти ошибки скрыты для всех пользователей.</p>',WpsSettings::TEXT_DOMAIN)
        );
    }

    /** Скрыть админ-уведомления для не админов */
    public static function fix_hideAdminNotifications()
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_wp_admin_notices']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_admin_notices']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                __('WordPress администратора уведомления отображаются для всех пользователей.',WpsSettings::TEXT_DOMAIN),
                __('<p>Эти уведомления отображаются в верхней части экрана по платформе WordPress, когда администраторов блог должен быть проинформирован о событии, которое произошло в WordPress, это может быть о доступном обновлении для платформы WordPress, плагин или тему, которая была обновлены или нуждается в обновлении или быть настроен, и т.д..</p>
                    <p>Эти уведомления должны рассматриваться только на веб-сайте и администраторы не видно каких-либо других зарегистрированных пользователей с этим веб-сайт.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрывать эти уведомления, если опция <strog>"%s"</strong> проверяется плагин на страницу настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Скрыть админ-уведомления для не админов')
            );
            return;
        }

        if (!WsdUtil::isAdministrator())
        {
            add_action('init', create_function('$a', "remove_action('init', 'wp_version_check');"), 2);
            add_filter('pre_option_update_core', create_function('$a', "return null;"));
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('Админ-уведомления будут отображаться только для администратора пользователям.',WpsSettings::TEXT_DOMAIN),
            __('<p>Эти уведомления отображаются в верхней части экрана по платформе WordPress, когда администраторов блог должен быть проинформирован о событии, которое произошло в WordPress, это может быть о доступном обновлении для платформы WordPress, плагин или тему, которая была обновлены или нуждается в обновлении или быть настроен, и т.д..</p>
                <p>В настоящее время, эти уведомления отображаются только для администраторов.</p>',WpsSettings::TEXT_DOMAIN));
    }

    /** Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг каталога */
    public static function fix_preventDirectoryListing()
    {
        global $wpsPluginAlertsArray;

        $actionName = $wpsPluginAlertsArray['fix_wp_dir_listing']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_dir_listing']['type'];
        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                __('Листинг директорий запрещен. Эта опция должна быть включена.',WpsSettings::TEXT_DOMAIN),
                __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                    Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                    Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически создавать пустой <strong>index.php</strong> Файл в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads если опция <strong>"%s"</strong> проверяются плагины на странице настроек.</p>',WpsSettings::TEXT_DOMAIN),
                    'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг каталога')
            );
            return;
        }
        else {
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('Список каталогов проверьте включена.',WpsSettings::TEXT_DOMAIN),
                __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                    Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                    Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }

        $data = '<?php exit;?>';
        $contentDir = trailingslashit(WP_CONTENT_DIR);
        $pluginsDir = $contentDir.'plugins';
        $themesDir = $contentDir.'themes';
        $uploadsDir = $contentDir.'uploads';

        $actionName = $wpsPluginAlertsArray['fix_wp_index_content']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_index_content']['type'];
        $file = $contentDir.'/index.php';
        if(is_dir($contentDir)){
            if(is_file($file)){
                self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                    sprintf(__('<strong>"%s"</strong> каталог защищен от листинга директорий.',WpsSettings::TEXT_DOMAIN),'/wp-content'),
                    __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                    Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                    Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                );
            }
            else {
                if (is_writable($contentDir))
                {
                    WsdUtil::writeFile($file,$data);
                    @chmod($file,'0644');
                    self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                        sprintf(__('<strong>"%s"</strong> каталог защищен от листинга директорий.',WpsSettings::TEXT_DOMAIN),'/wp-content'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                    );
                }
                else {
                    self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                        sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN),
                        sprintf(__('<p>Этот плагин может автоматически создавать пустой <strong>index.php</strong> Файл в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads если опция <strong>"%s"</strong> проверяются плагины на странице настроек.</p>',WpsSettings::TEXT_DOMAIN),
                            'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг каталога')
                    );
                }
            }
        }

        $actionName = $wpsPluginAlertsArray['fix_wp_index_plugins']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_index_plugins']['type'];
        $file = $pluginsDir.'/index.php';
        if(is_dir($pluginsDir)){
            if(is_file($file)){
                self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                    sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/plugins'),
                    __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                );
            }
            else {
                if (is_writable($pluginsDir))
                {
                    WsdUtil::writeFile($file,$data);
                    @chmod($file,'0644');
                    self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                        sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/plugins'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                    );
                }
                else {
                    self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                        sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/plugins'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN),
                        sprintf(__('<p>Этот плагин может автоматически создавать пустой <strong>index.php</strong> Файл в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads если опция <strong>"%s"</strong> проверяются плагины на странице настроек.</p>',WpsSettings::TEXT_DOMAIN),
                            'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг каталога')
                    );
                }
            }
        }

        $actionName = $wpsPluginAlertsArray['fix_wp_index_themes']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_index_themes']['type'];
        $file = $themesDir.'/index.php';
        if(is_dir($themesDir)){
            if(is_file($file)){
                self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                    sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/themes'),
                    __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                );
            }
            else {
                if (is_writable($themesDir))
                {
                    WsdUtil::writeFile($file,$data);
                    @chmod($file,'0644');
                    self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                        sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/themes'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                    );
                }
                else {
                    self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                        sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/themes'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN),
                        sprintf(__('<p>Этот плагин может автоматически создавать пустой <strong>index.php</strong> Файл в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads если опция <strong>"%s"</strong> проверяются плагины на странице настроек.</p>',WpsSettings::TEXT_DOMAIN),
                            'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг каталога')
                    );
                }
            }
        }

        $actionName = $wpsPluginAlertsArray['fix_wp_index_uploads']['name'];
        $alertType = $wpsPluginAlertsArray['fix_wp_index_uploads']['type'];
        $file = $uploadsDir.'/index.php';
        if(is_dir($uploadsDir)){
            if(is_file($file)){
                self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                    sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/uploads'),
                    __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                );
            }
            else {
                if (is_writable($uploadsDir))
                {
                    WsdUtil::writeFile($file,$data);
                    @chmod($file,'0644');
                    self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                        sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/uploads'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN)
                    );
                }
                else {
                    self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                        sprintf(__('<strong>"%s"</strong> Каталог не является безопасным от листинг каталога.',WpsSettings::TEXT_DOMAIN),'/wp-content/uploads'),
                        __('<p>Список каталогов дает злоумышленнику полный индекс всех ресурсов, расположенных внутри каталога.
                            Конкретные риски и последствия различаются в зависимости от того, какие файлы перечислены и доступны.
                            Поэтому, важно защитить ваши каталоги, имея пустой index.php или index.htm файлов внутри них.</p>',WpsSettings::TEXT_DOMAIN),
                        sprintf(__('<p>Этот плагин может автоматически создавать пустой <strong>index.php</strong> Файл в следующих каталогах: wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads если опция <strong>"%s"</strong> проверяются плагины на странице настроек.</p>',WpsSettings::TEXT_DOMAIN),
                            'Попробуйте создать файл index.php в wp-content, wp-content/plugins, wp-content/themes и wp-content/uploads директориях, чтобы предотвратить листинг каталога')
                    );
                }
            }
        }
    }

    /** Удалить параметр от URL-адреса версии */
    public static function fix_removeWpVersionFromLinks($src = '')
    {
        global $wpsPluginAlertsArray;
        $actionName = $wpsPluginAlertsArray['fix_remove_wp_version_links']['name'];
        $alertType = $wpsPluginAlertsArray['fix_remove_wp_version_links']['type'];

        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_CRITICAL,
                __('Версия WordPress отображается в ссылках для всех пользователей',WpsSettings::TEXT_DOMAIN),
                __('<p>По умолчанию, WordPress будет отображать текущую версию в ссылках на яваскрипта скриптов или стилей. Поэтому, если кто-то имеет доступ к этой информации может быть риск для безопасности, потому что если хакер знает, какая версия WordPress сайт работает, он может сделать это легче для него целевой известную проблему безопасности WordPress.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически скрывать версию WordPress от ссылкам если опция <strong>"%s"</strong> проверяются плагины на странице настроек.</p>',WpsSettings::TEXT_DOMAIN), 'Удалить параметр от URL-адреса версии')
            );
            return;
        }

        if (!WsdUtil::isAdministrator())
        {
            add_filter('script_loader_src', array('WsdSecurityHelper', '__removeWpVersionFromLinks'));
            add_filter('style_loader_src', array('WsdSecurityHelper', '__removeWpVersionFromLinks'));
        }
        self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
            __('WordPress версии отображается в ссылках только для пользователей администраторов.',WpsSettings::TEXT_DOMAIN),
            __('<p>По умолчанию, WordPress будет отображать текущую версию в ссылках на яваскрипта скриптов или стилей. Поэтому, если кто-то имеет доступ к этой информации может быть риск для безопасности, потому что если хакер знает, какая версия WordPress сайт работает, он может сделать это легче для него целевой известную проблему безопасности WordPress.</p>',WpsSettings::TEXT_DOMAIN)
        );
    }

    /** Очистите содержимое файла readme.html из корневого каталога */
    public static function fix_emptyReadmeFileFromRoot()
    {
        global $wpsPluginAlertsArray;

        // if the file is 404 or not readable or empty, there is no need to display the alert
        $filePath = trailingslashit(ABSPATH).'readme.html';
        if(! is_file($filePath)){ return; }
        if(! is_readable($filePath)) { return; }
        $fsize = @filesize($filePath);
        if(false !== $fsize && $fsize == 0) { return; }

        $actionName = $wpsPluginAlertsArray['fix_empty_root_readme_file']['name'];
        $alertType = $wpsPluginAlertsArray['fix_empty_root_readme_file']['type'];
        /* This check is important so this function will run only if the user enables it. */
        if(! self::isSettingEnabled(__FUNCTION__)){
            self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                sprintf(__('Очистка содержимого <strong>"%s"</strong> файл из <strong>"%s"</strong> отключенной директории.',WpsSettings::TEXT_DOMAIN), 'readme.html', 'root'),
                __('<p>Установка WordPress по умолчанию содержит readme.html файл. Этот файл представляет собой простой HTML-файл, который не содержит исполняемый контент, который может быть использована хакерами или злоумышленников.
                        Тем не менее, этот файл может предоставить хакерам версию вашей установки WordPress, поэтому важно, чтобы либо удалить этот файл или сделать его недоступным для посетителей.</p>',WpsSettings::TEXT_DOMAIN),
                sprintf(__('<p>Этот плагин может автоматически удалять его содержимое (предполагается, что файл существует), если опция <strong>"%s"</strong> проверяет плагины на странице настроек.
                    Вы также можете удалить этот файл вручную при подключении к веб-сайт через FTP соединение.</p>',WpsSettings::TEXT_DOMAIN), 'Очистите содержимое файла readme.html из корневого каталога')
            );
            return;
        }
        else {
            // clear Содержание из file
            $result = file_put_contents($filePath,'');
            // failure
            if(false === $result){
                // todo
                self::alert($actionName, $alertType, WpsSettings::ALERT_MEDIUM,
                    sprintf(__('Содержание из <strong>"%s"</strong> файл из <strong>"%s"</strong> Каталог не может быть удален.',WpsSettings::TEXT_DOMAIN), 'readme.html', 'root'),
                    __('<p>Установка WordPress по умолчанию содержит readme.html файл. Этот файл представляет собой простой HTML-файл, который не содержит исполняемый контент, который может быть использована хакерами или злоумышленников.
                        Тем не менее, этот файл может предоставить хакерам версию вашей установки WordPress, поэтому важно, чтобы либо удалить этот файл или сделать его недоступным для посетителей.</p>',WpsSettings::TEXT_DOMAIN),
                    __('<p>Мы столкнулись с ошибкой при попытке удалить содержимое этого файла, таким образом, вы должны будете вручную удалить ее или сделать ее недоступной из ваших посетителей, установив разрешения для файлов <strong>0440</strong> или ниже.</p>',WpsSettings::TEXT_DOMAIN)
                );
                return;
            }
            self::alert($actionName, $alertType, WpsSettings::ALERT_INFO,
                __('Содержание из readme.html файл из root Каталог был удален.',WpsSettings::TEXT_DOMAIN),
                __('<p>Установка WordPress по умолчанию содержит readme.html файл. Этот файл представляет собой простой HTML-файл, который не содержит исполняемый контент, который может быть использована хакерами или злоумышленников.
                        Тем не менее, этот файл может предоставить хакерам версию вашей установки WordPress, поэтому важно, чтобы либо удалить этот файл или сделать его недоступным для посетителей.</p>',WpsSettings::TEXT_DOMAIN)
            );
        }

    }

}

class WsdSecurityHelper
{
    /**
     * @private
     * @param $src
     * @return mixed
     */
    public static function __removeWpVersionFromLinks($src)
    {
        // Just the URI without the query string.
        $src = preg_replace("/\?ver=(.*)/mi", '', $src);
        return $src;
    }

}